@@ -158,11 +158,7 @@ def get4():
       if randmoves in moves and scramble[-2] in moves and scramble[-4] in moves:
         randmoves=random.choice(wide_turns)
 
-      while randmoves in list1 and scramble[-2] in list1 and scramble[-4] in list1:
-        randmoves=random.choice(wide_turns)
-      while randmoves in list2 and scramble[-2] in list2 and scramble[-4] in list2:
-        randmoves=random.choice(wide_turns)
-      while randmoves in list3 and scramble[-2] in list3 and scramble[-4] in list3:
+      while (randmoves in list1 and scramble[-2] in list1 and scramble[-4] in list1) or (randmoves in list2 and scramble[-2] in list2 and scramble[-4] in list2) or (randmoves in list3 and scramble[-2] in list3 and scramble[-4] in list3):
         randmoves=random.choice(wide_turns)
       usedmoves.append(randmoves)
       scramble.append(randmoves)
@@ -174,11 +170,7 @@ def get4():
       randmoves1=random.choice(wide_turns)
       if randmoves1 in moves and scramble[-2] in moves and scramble[-4] in moves:
         randmoves1=random.choice(wide_turns)
-      while randmoves1 in list1 and scramble[-2] in list1 and scramble[-4] in list1:
-        randmoves1=random.choice(wide_turns)
-      while randmoves1 in list2 and scramble[-2] in list2 and scramble[-4] in list2:
-        randmoves1=random.choice(wide_turns)
-      while randmoves1 in list3 and scramble[-2] in list3 and scramble[-4] in list3:
+      while (randmoves1 in list1 and scramble[-2] in list1 and scramble[-4] in list1) or (randmoves1 in list2 and scramble[-2] in list2 and scramble[-4] in list2) or (randmoves1 in list3 and scramble[-2] in list3 and scramble[-4] in list3):
         randmoves1=random.choice(wide_turns)
 
       scramble.append(randmoves1)
@@ -204,12 +196,9 @@ def get5():
     if i % 2 ==0:
       randmoves=random.choice(moves)
       if i>1:
-        while randmoves in list1 and scramble[-2] in list1 and scramble[-4] in list1:
+        while (randmoves in list1 and scramble[-2] in list1 and scramble[-4] in list1) or (randmoves in list2 and scramble[-2] in list2 and scramble[-4] in list2) or (randmoves in list3 and scramble[-2] in list3 and scramble[-4] in list3):
           randmoves=random.choice(moves)
-        while randmoves in list2 and scramble[-2] in list2 and scramble[-4] in list2:
-          randmoves=random.choice(moves)
-        while randmoves in list3 and scramble[-2] in list3 and scramble[-4] in list3:
-          randmoves=random.choice(moves)                
+
       usedmoves.append(randmoves)
       scramble.append(randmoves)
       scramble.append(random.choice(turns))
@@ -220,14 +209,11 @@ def get5():
     else:
       randmoves1=random.choice(moves)
       if i>2:
-        while randmoves1 in list1 and scramble[-2] in list1 and scramble[-4] in list1:
-          randmoves1=random.choice(moves)
-        while randmoves1 in list2 and scramble[-2] in list2 and scramble[-4] in list2:
-          randmoves1=random.choice(moves)
-        while randmoves1 in list3 and scramble[-2] in list3 and scramble[-4] in list3:
+        randmoves1=random.choice(moves)
+        while (randmoves1 in list1 and scramble[-2] in list1 and scramble[-4] in list1) or (randmoves1 in list2 and scramble[-2] in list2 and scramble[-4] in list2) or (randmoves1 in list3 and scramble[-2] in list3 and scramble[-4] in list3):
           randmoves1=random.choice(moves)
 
-      randmoves1=random.choice(moves)
+
       scramble.append(randmoves1)
       usedmoves1.append(randmoves1)
       scramble.append(random.choice(turns))
